summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttViewTaskLink.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdgantt/KDGanttViewTaskLink.cpp')
-rw-r--r--kdgantt/KDGanttViewTaskLink.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kdgantt/KDGanttViewTaskLink.cpp b/kdgantt/KDGanttViewTaskLink.cpp
index 2f5ca479f..4d21073e7 100644
--- a/kdgantt/KDGanttViewTaskLink.cpp
+++ b/kdgantt/KDGanttViewTaskLink.cpp
@@ -26,8 +26,8 @@
** licensing are not clear to you.
**
** As a special exception, permission is given to link this program
** with any edition of Qt, and distribute the resulting executable,
** without including the source code for Qt in the source distribution.
**
**********************************************************************/
@@ -236,8 +236,8 @@ void KDGanttViewTaskLink::initTaskLink()
setWhatsThisText( "Tasklink" );
myTimeTable->myTaskLinkList.append(this);
setHighlight( false);
- setHighlightColor(Qt::red );
- setColor(Qt::black);
+ setHighlightColor(TQt::red );
+ setColor(TQt::black);
setVisible(true);
}
@@ -268,7 +268,7 @@ void KDGanttViewTaskLink::showMe( bool visible )
TQPen p;
TQBrush b;
p.setWidth(wid);
- b.setStyle(Qt::SolidPattern);
+ b.setStyle(TQt::SolidPattern);
if (ishighlighted) {
b.setColor(myColorHL);
p.setColor(myColorHL);
@@ -333,7 +333,7 @@ void KDGanttViewTaskLink::showMeType( bool visible )
TQPen p;
TQBrush b;
p.setWidth(wid);
- b.setStyle(Qt::SolidPattern);
+ b.setStyle(TQt::SolidPattern);
if (ishighlighted) {
b.setColor(myColorHL);
p.setColor(myColorHL);
@@ -732,13 +732,13 @@ TQPtrList<KDGanttViewItem> KDGanttViewTaskLink::to() const
Creates a DOM node that describes this task link.
\param doc the DOM document to which the node belongs
- \param parentElement the element into which to insert this node
+ \param tqparentElement the element into which to insert this node
*/
void KDGanttViewTaskLink::createNode( TQDomDocument& doc,
- TQDomElement& parentElement )
+ TQDomElement& tqparentElement )
{
TQDomElement taskLinkElement = doc.createElement( "TaskLink" );
- parentElement.appendChild( taskLinkElement );
+ tqparentElement.appendChild( taskLinkElement );
TQDomElement fromItemsElement = doc.createElement( "FromItems" );
taskLinkElement.appendChild( fromItemsElement );
@@ -870,13 +870,13 @@ KDGanttViewTaskLink* KDGanttViewTaskLink::createFromDomElement( TQDomElement& el
TQPtrList<KDGanttViewItem> toItemList;
for( TQStringList::const_iterator fromIt = fromList.begin();
fromIt != fromList.end(); ++fromIt ) {
- KDGanttViewItem* item = KDGanttViewItem::find( *fromIt );
+ KDGanttViewItem* item = KDGanttViewItem::tqfind( *fromIt );
if( item )
fromItemList.append( item );
}
for( TQStringList::const_iterator toIt = toList.begin();
toIt != toList.end(); ++toIt ) {
- KDGanttViewItem* item = KDGanttViewItem::find( *toIt );
+ KDGanttViewItem* item = KDGanttViewItem::tqfind( *toIt );
if( item )
toItemList.append( item );
}
@@ -898,7 +898,7 @@ KDGanttViewTaskLink* KDGanttViewTaskLink::createFromDomElement( TQDomElement& el
tl->setHighlightColor( highlightColor );
tl->setTooltipText( tooltipText );
tl->setWhatsThisText( whatsThisText );
- KDGanttViewTaskLinkGroup* gr = KDGanttViewTaskLinkGroup::find( group );
+ KDGanttViewTaskLinkGroup* gr = KDGanttViewTaskLinkGroup::tqfind( group );
if( gr )
tl->setGroup( gr );
@@ -26,8 +26,8 @@
**
** As a special exception, permission is given to link this program
- ** with any edition of Qt, and distribute the resulting executable,
- ** without including the source code for Qt in the source distribution.
+ ** with any edition of TQt, and distribute the resulting executable,
+ ** without including the source code for TQt in the source distribution.
**
**********************************************************************/